
## for parsing GenePattern inputs
suppressMessages(suppressWarnings(library(getopt)))
suppressMessages(suppressWarnings(library(optparse)))

## libraries needed by this module
suppressMessages (suppressWarnings (library (ggplot2)))
suppressMessages (suppressWarnings (library (reshape)))
suppressMessages (suppressWarnings (library (RColorBrewer)))

sessionInfo ()


paired.colors <- function (sets, types) {
  # types is 1, 2, or 3
  
  reds <- brewer.pal (7, 'Reds')
  greens <- brewer.pal (7, 'Greens')
  blues <- brewer.pal (7, 'Blues')
  
  colors <- NULL
  for (i in seq (7, (7-2*(sets-1)), -2)) {
    colors <- c (colors, reds[i])
    if (types==3) colors <- c (colors, greens[i], blues[i])
    else if (types==2) colors <- c (colors, greens[i])
  }
  
  return (colors)
}


read.gct.data <- function (f) {
  d <- read.gct (f)
  return (d[,3:ncol(d)])
}



## plot individual profiles
plot.profiles <- function (d.in, out.file, title) {
  d <- melt (d.in)
  colnames (d) <- c ('sample', 'ratio')
  s <- data.frame (sample=colnames (d.in), type=cls)
  d <- merge (d,s)
  g <- ggplot (aes (x=ratio, color=type), data=d) + geom_density(size=1) + xlab ('log ratio') + 
    ggtitle (title) + facet_wrap (~sample, ncol=5) + theme_minimal() +
    # theme(panel.background=element_rect(fill='gray95')) + 
    scale_color_manual (name='Type', values=paired.colors (1, nlevels (d[,'type'])), 
                        labels=levels (d[,'type']))
  ggsave (out.file, device='pdf', width=11)
}



# Get the command line arguments.  We'll process these with optparse.
# https://cran.r-project.org/web/packages/optparse/index.html
arguments <- commandArgs(trailingOnly=TRUE)

# Declare an option list for optparse to use in parsing the command line.
option_list <- list(
  # Note: it's not necessary for the names to match here, it's just a convention
  # to keep things consistent.
  make_option("--libdir", dest="libdir"),
  make_option("--input.file", dest="input.file"),
  make_option("--output.file", dest="output.file"),
  make_option("--data.type", dest="type", default="proteome"),
  make_option("--cls.file", dest="group.cls", type='character', default=NULL)
)

# Parse the command line arguments with the option list, printing the result
# to give a record as with sessionInfo.
opt <- parse_args (OptionParser (option_list=option_list), positional_arguments=TRUE, args=arguments)
print (opt)
opts <- opt$options

## read in supporting functions
source (file.path (opts$libdir, "io.r"))

## extract options into appropriate variable
type <- opts$type
input.file <- opts$input.file

## input data
data <- read.gct.data ( input.file )
if (is.null(opts$group.cls)) {
  cls <- rep (type, ncol (data))
} else cls <- read.cls ( opts$group.cls )


## plot
plot.profiles (data, opts$output.file, paste (toupper (type), ': Distribution of log ratios', sep=''))

